@@ -27,7 +27,7 @@ object_name = os
 __package__ = os.path.basename(os.path.dirname(__file__))
 __author__ = "Dillon"
 __email__ = "aa269440877@outlook.com"
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 __url__ = "https://gitee.com/ld269440877/tools/blob/master/my_modules/dir_objectName.py"
 __license__ = "MIT Licence"
 
@@ -485,6 +485,23 @@ def aprint(sequence_or_mapping, columns=4, width=30, pattern=r"^[^_]"):
     print()
 
 
+def importModules(package_name, pattern=r"^[^_]"):
+    modules = list()
+    package_folder = getattr(package_name, __path__, list())[0]
+    if not package_folder:
+        return list()
+    for module in os.listdir(package_folder):
+        try:
+            if re.search(pattern, module):
+                module = f"{package_name}." + os.path.splitext(module)[0]
+                importlib.import_module(module)
+                modules.append(module)
+            else:
+                continue
+        except ImportError as e:
+            print(f"import {module} error!")
+    return modules
+
 
 def help():
     print("__file__", __file__, "\n__doc__", __doc__)
